@@ -1534,7 +1534,7 @@ class BrokerClient(RESTClient):
         # checking to see if we specified at least one param
         params = filter.to_request_fields() if filter is not None else {}
 
-        if "symbols" in params and type(params["symbols"]) is List:
+        if "symbols" in params and isinstance(params["symbols"], list):
             params["symbols"] = ",".join(params["symbols"])
 
         response = self.get(f"/trading/accounts/{account_id}/orders", params)
@@ -1681,7 +1681,7 @@ class BrokerClient(RESTClient):
         """
         params = filter.to_request_fields() if filter else {}
 
-        if "ca_types" in params and type(params["ca_types"]) is List:
+        if "ca_types" in params and isinstance(params["ca_types"], list):
             params["ca_types"] = ",".join(params["ca_types"])
 
         response = self.get("/corporate_actions/announcements", params)
